==> mailer-0.8.12.tar.gz: lib/src/envelope.dart <==
part of mailer;

/**
 * This class represents an envelope that can be sent to someone/some people.
 *
 * Use [text] to specify plaintext body or [html] to specify HTML body. Use both to provide a fallback for old email clients.
 *
 * Recipients are defined as a [List] of [String]s.
 */
class Envelope {
  List<String> recipients = [];
  List<String> ccRecipients = [];
  List<String> bccRecipients = [];
  List<Attachment> attachments = [];
  String from = 'anonymous@${Platform.localHostname}';
  String fromName;
  String subject;
  String text;
  String html;
  String identityString = 'mailer';
  Encoding encoding = UTF8;

  int _counter = 0;

  /**
   * Returns the envelope as a String that is suitable for use in SMTP DATA section.
   *
   * This method automatically sanitizes all fields.
   */
  Future<String> getContents() {
    return new Future(() {
      var buffer = new StringBuffer();

      if (subject != null) buffer.write('Subject: ${_sanitizeField(subject)}\n');

      if (from != null) {
        var fromData = _sanitizeEmail(from);

        if (fromName != null) {
          fromData = '$fromName <$fromData>';
        }

        buffer.write('From: $fromData\n');
      }

      if (recipients != null && recipients.length > 0) {
        var to = recipients.map((recipient) => _sanitizeEmail(recipient)).toList().join(',');
        buffer.write('To: $to\n');
      }

      if (!this.ccRecipients.isEmpty) {
        var cc = ccRecipients.map((recipient) => _sanitizeEmail(recipient)).toList().join(',');
        buffer.write('cc: $cc\n');
      }

      if (!this.bccRecipients.isEmpty) {
        var bcc = bccRecipients.map((recipient) => _sanitizeEmail(recipient)).toList().join(',');
        buffer.write('bcc: $bcc\n');
      }

      // Since TimeZone is not implemented in DateFormat we need to use UTC for proper Date header generation time
      buffer.write('Date: ' + new DateFormat('EEE, dd MMM yyyy HH:mm:ss +0000').format(new DateTime.now().toUtc()) + '\n');
      buffer.write('X-Mailer: Dart Mailer library\n');
      buffer.write('Mime-Version: 1.0\n');

      // Create boundary string.
      var boundary = '$identityString-?=_${++_counter}-${new DateTime.now().millisecondsSinceEpoch}';

      // Alternative or mixed?
      var multipartType = html != null && text != null ? 'alternative' : 'mixed';

      buffer.write('Content-Type: multipart/$multipartType; boundary="$boundary"\n\n');

      // Insert text message.
      if (text != null) {
        buffer.write('--$boundary\n');
        buffer.write('Content-Type: text/plain; charset="${encoding.name}"\n');
        buffer.write('Content-Transfer-Encoding: 7bit\n\n');
        buffer.write('$text\n\n');
      }

      // Insert HTML message.
      if (html != null) {
        buffer.write('--$boundary\n');
        buffer.write('Content-Type: text/html; charset="${encoding.name}"\n');
        buffer.write('Content-Transfer-Encoding: 7bit\n\n');
        buffer.write('$html\n\n');
      }

      // Add all attachments.
      return Future.forEach(attachments, (attachment) {
        var filename = basename(attachment.file.path);

        return attachment.file.readAsBytes().then((bytes) {
          // Create a chunk'd (76 chars per line) base64 string.
          var contents = CryptoUtils.bytesToBase64(bytes, addLineSeparator: true);

          buffer.write('--$boundary\n');
          buffer.write('Content-Type: ${_getMimeType(attachment.file.path)}; name="$filename"\n');
          buffer.write('Content-Transfer-Encoding: base64\n');
          buffer.write('Content-Disposition: attachment; filename="$filename"\n\n');
          buffer.write('$contents\n\n');
        });
      }).then((_) {
        buffer.write('--$boundary--\n\r\n.'); // Note. the \r actually needs to be there.

        return buffer.toString();
      });
    });
  }
}

String _getMimeType(String path) {
  final mtype = lookupMimeType(path);
  return mtype != null ? mtype: 'application/octet-stream';
}

==> mailer-1.0.1.tar.gz: lib/src/envelope.dart <==
part of mailer;

/**
 * This class represents an envelope that can be sent to someone/some people.
 *
 * Use [text] to specify plaintext body or [html] to specify HTML body. Use both to provide a fallback for old email clients.
 *
 * Recipients are defined as a [List] of [String]s.
 */
class Envelope {
  List<String> recipients = [];
  List<String> ccRecipients = [];
  List<String> bccRecipients = [];
  List<Attachment> attachments = [];
  String from = 'anonymous@${Platform.localHostname}';
  String fromName;
  String subject;
  String text;
  String html;
  String identityString = 'mailer';
  Encoding encoding = UTF8;

  bool _isDelivered = false;
  int _counter = 0;

  /**
   * Returns the envelope as a String that is suitable for use in SMTP DATA section.
   *
   * This method automatically sanitizes all fields.
   */
  Future<String> getContents() {
    return new Future(() {
      var buffer = new StringBuffer();

      if (subject != null) buffer.write('Subject: ${_sanitizeField(subject)}\n');

      if (from != null) {
        var fromData = _sanitizeEmail(from);

        if (fromName != null) {
          fromData = '$fromName <$fromData>';
        }

        buffer.write('From: $fromData\n');
      }

      if (recipients != null && !recipients.isEmpty) {
        var to = recipients.map(_sanitizeEmail).join(',');
        buffer.write('To: $to\n');
      }

      if (ccRecipients != null && !ccRecipients.isEmpty) {
        var cc = ccRecipients.map(_sanitizeEmail).join(',');
        buffer.write('cc: $cc\n');
      }

      if (bccRecipients != null && !bccRecipients.isEmpty) {
        var bcc = bccRecipients.map(_sanitizeEmail).join(',');
        buffer.write('bcc: $bcc\n');
      }

      // Since TimeZone is not implemented in DateFormat we need to use UTC for proper Date header generation time
      buffer.write('Date: ' + new DateFormat('EEE, dd MMM yyyy HH:mm:ss +0000').format(new DateTime.now().toUtc()) + '\n');
      buffer.write('X-Mailer: Dart Mailer library\n');
      buffer.write('Mime-Version: 1.0\n');

      // Create boundary string.
      var boundary = '$identityString-?=_${++_counter}-${new DateTime.now().millisecondsSinceEpoch}';

      // Alternative or mixed?
      var multipartType = html != null && text != null ? 'alternative' : 'mixed';

      buffer.write('Content-Type: multipart/$multipartType; boundary="$boundary"\n\n');

      // Insert text message.
      if (text != null) {
        buffer.write('--$boundary\n');
        buffer.write('Content-Type: text/plain; charset="${encoding.name}"\n');
        buffer.write('Content-Transfer-Encoding: 7bit\n\n');
        buffer.write('$text\n\n');
      }

      // Insert HTML message.
      if (html != null) {
        buffer.write('--$boundary\n');
        buffer.write('Content-Type: text/html; charset="${encoding.name}"\n');
        buffer.write('Content-Transfer-Encoding: 7bit\n\n');
        buffer.write('$html\n\n');
      }

      // Add all attachments.
      return Future.forEach(attachments, (attachment) {
        var filename = basename(attachment.file.path);

        return attachment.file.readAsBytes().then((bytes) {
          // Create a chunk'd (76 chars per line) base64 string.
          var contents = CryptoUtils.bytesToBase64(bytes, addLineSeparator: true);

          buffer.write('--$boundary\n');
          buffer.write('Content-Type: ${_getMimeType(attachment.file.path)}; name="$filename"\n');
          buffer.write('Content-Transfer-Encoding: base64\n');
          buffer.write('Content-Disposition: attachment; filename="$filename"\n\n');
          buffer.write('$contents\n\n');
        });
      }).then((_) {
        buffer.write('--$boundary--\n\r\n.'); // Note. the \r actually needs to be there.

        return buffer.toString();
      });
    });
  }
}

String _getMimeType(String path) {
  final mtype = lookupMimeType(path);
  return mtype != null ? mtype: 'application/octet-stream';
}
